@@ -3,7 +3,7 @@ from io import BytesIO
 from pathlib import Path
 
 import pytest
-from python_calamine import CalamineWorkbook
+from python_calamine import CalamineWorkbook, PasswordError, WorksheetNotFound, ZipError
 
 PATH = Path(__file__).parent / "data"
 
@@ -219,13 +219,75 @@ def test_nrows():
 
 
 @pytest.mark.parametrize(
-    "obj",
+    "path",
     [
+        PATH / "base.xlsx",
+        PATH / "base.xls",
+        PATH / "base.xlsb",
+        PATH / "base.ods",
+    ],
+)
+def test_worksheet_errors(path):
+    reader = CalamineWorkbook.from_object(path)
+    with pytest.raises(WorksheetNotFound):
+        reader.get_sheet_by_name("Sheet4")
+
+
+@pytest.mark.parametrize(
+    "path",
+    [
+        PATH / "password.xlsx",
+        PATH / "password.xls",
+        PATH / "password.xlsb",
+        PATH / "password.ods",
+    ],
+)
+def test_password_errors(path):
+    with pytest.raises(PasswordError):
+        CalamineWorkbook.from_object(path)
+
+
+@pytest.mark.parametrize(
+    "path",
+    [
+        PATH / "empty_file.xlsx",
+        PATH / "empty_file.xlsb",
+        PATH / "empty_file.ods",
+    ],
+)
+def test_zip_errors(path):
+    with pytest.raises(ZipError):
+        CalamineWorkbook.from_path(path)
+
+
+@pytest.mark.parametrize(
+    "path",
+    [
+        PATH / "non_existent_file.xlsx",
+        PATH / "non_existent_file.xls",
+        PATH / "non_existent_file.xlsb",
+        PATH / "non_existent_file.ods",
+    ],
+)
+def test_io_errors(path):
+    with pytest.raises(IOError):
+        CalamineWorkbook.from_path(path)
+
+
+@pytest.mark.parametrize(
+    "path",
+    [
+        PATH / "base.xlsx",
         (PATH / "base.xlsx").as_posix(),
     ],
 )
-def test_path(obj):
-    CalamineWorkbook.from_path(obj)
+def test_path(path):
+    CalamineWorkbook.from_path(path)
+
+
+def test_path_error():
+    with pytest.raises(TypeError):
+        CalamineWorkbook.from_path(object())
 
 
 @pytest.mark.parametrize(
